@@ -10,6 +10,10 @@ package LaTeX::TOM::Tree;
 
 use strict;
 
+use Carp qw(croak);
+
+our $VERSION = '0.02';
+
 # "constructor"
 #
 sub new {
@@ -24,7 +28,7 @@ sub new {
        nodes  => $nodes,
     };
 
-    return bless $self, ref($class) || $class;
+    return bless $self;
 }
 
 # make a copy of a tree, recursively
@@ -140,7 +144,7 @@ sub indexableText {
     my $text = join (' ', @$pt);
 
     # kill leftover commands
-    $text =~ s/\\\w+//gso;
+    $text =~ s/\\\w+\*?//gso;
 
     # kill nonpunctuation
     $text =~ s/[^\w\-0-9\s]//gso;
@@ -279,6 +283,11 @@ sub getNodesByCondition {
     my $tree = shift;
     my $condition = shift;
 
+    # XXX rt #48551 - string eval no longer supported (12/08/2009)
+    unless (ref $condition eq 'CODE') {
+        croak 'getNodesByCondition(): code reference expected';
+    }
+
     my @nodelist;
 
     foreach my $node (@{$tree->{nodes}}) {
@@ -286,7 +295,7 @@ sub getNodesByCondition {
         # evaluate the perl code condition and if the result evaluates to true,
         # push this node
         #
-        if (eval $condition) {
+        if ($condition->($node)) {
             push @nodelist, $node;
         }
 
@@ -302,14 +311,23 @@ sub getCommandNodesByName {
     my $tree = shift;
     my $name = shift;
 
-    return $tree->getNodesByCondition("\$node->{type} eq 'COMMAND' && \$node->{command} eq '$name'");
+    return $tree->getNodesByCondition(
+        sub { my $node = shift; return ($node->{type} eq 'COMMAND' && $node->{command} eq $name); }
+    );
 }
 
 sub getEnvironmentsByName {
     my $tree = shift;
     my $name = shift;
 
-    return $tree->getNodesByCondition("\$node->{type} eq 'ENVIRONMENT' && \$node->{class} eq '$name'");
+    return $tree->getNodesByCondition(
+        sub { my $node = shift; return ($node->{type} eq 'ENVIRONMENT' && $node->{class} eq $name); }
+    );
+}
+
+sub getFirstNode {
+    my $tree = shift;
+    return $tree->{nodes}[0];
 }
 
 1;
